using Microsoft.AspNetCore.Mvc;
using ldap_cesi.DTOs.Inputs.Role;
using ldap_cesi.Services.Interfaces;
using System.Threading.Tasks;

namespace ldap_cesi.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class RoleController : ControllerBase
    {
        private readonly IRoleService _roleService;

        public RoleController(IRoleService roleService)
        {
            _roleService = roleService;
        }

        // GET: api/Role
        [HttpGet]
        public async Task<IActionResult> GetAllRoles()
        {
            var result = await _roleService.GetAll();
            if (result.Success)
            {
                return Ok(result.Data);
            }
            return StatusCode(result.StatusCode, result.Message);
        }

        // GET: api/Role/{id}
        [HttpGet("{id}")]
        public async Task<IActionResult> GetRoleById(int id)
        {
            var result = await _roleService.GetById(id);
            if (result.Success)
            {
                return Ok(result.Data);
            }
            return StatusCode(result.StatusCode, result.Message);
        }

        // POST: api/Role
        [HttpPost]
        public async Task<IActionResult> CreateRole([FromBody] RoleCreateDto roleDto)
        {
            var result = await _roleService.Create(roleDto);
            if (result.Success)
            {
                return CreatedAtAction(nameof(GetRoleById), new { id = result.Data }, result.Data);
            }
            return StatusCode(result.StatusCode, result.Message);
        }

        // PUT: api/Role/{id}
        [HttpPut("{id}")]
        public async Task<IActionResult> UpdateRole(int id, [FromBody] RoleUpdateDto roleDto)
        {
            if (id != roleDto.Id)
            {
                return BadRequest("Role ID mismatch");
            }

            var result = await _roleService.Update(roleDto);
            if (result.Success)
            {
                return NoContent();
            }
            return StatusCode(result.StatusCode, result.Message);
        }

        // DELETE: api/Role/{id}
        [HttpDelete("{id}")]
        public async Task<IActionResult> DeleteRole(int id)
        {
            var result = await _roleService.Delete(id);
            if (result.Success)
            {
                return NoContent();
            }
            return StatusCode(result.StatusCode, result.Message);
        }
    }
}
